pub struct CreateFile;Trait Implementations
Sourceimpl GraphQLQuery for CreateFile
impl GraphQLQuery for CreateFile
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for CreateFile
impl RefUnwindSafe for CreateFile
impl Send for CreateFile
impl Sync for CreateFile
impl Unpin for CreateFile
impl UnwindSafe for CreateFile