pub struct RegisterUploadedFile;Trait Implementations
Sourceimpl GraphQLQuery for RegisterUploadedFile
impl GraphQLQuery for RegisterUploadedFile
Sourcetype Variables = Variables
type Variables = Variables
The shape of the variables expected by the query. This should be a generated struct most of the time.
Sourcetype ResponseData = ResponseData
type ResponseData = ResponseData
The top-level shape of the response data (the
data field in the GraphQL response). In practice this should be generated, since it is hard to write by hand without error.Auto Trait Implementations
impl Freeze for RegisterUploadedFile
impl RefUnwindSafe for RegisterUploadedFile
impl Send for RegisterUploadedFile
impl Sync for RegisterUploadedFile
impl Unpin for RegisterUploadedFile
impl UnwindSafe for RegisterUploadedFile